summaryrefslogtreecommitdiffhomepage
path: root/examples/models/models_loading_gltf.c
diff options
context:
space:
mode:
authorRay <[email protected]>2022-07-01 14:02:30 +0200
committerRay <[email protected]>2022-07-01 14:02:30 +0200
commit061e828524e91ddb04dec6b941b67b15bccf736e (patch)
tree1ff0a51331fe946d807485be2146d053b5ec024e /examples/models/models_loading_gltf.c
parentb84fc30284e2a254fd3aab9417765c25c941480d (diff)
downloadraylib-061e828524e91ddb04dec6b941b67b15bccf736e.tar.gz
raylib-061e828524e91ddb04dec6b941b67b15bccf736e.zip
REVIEWED: example: gltf models loading -WIP-
Diffstat (limited to 'examples/models/models_loading_gltf.c')
-rw-r--r--examples/models/models_loading_gltf.c49
1 files changed, 9 insertions, 40 deletions
diff --git a/examples/models/models_loading_gltf.c b/examples/models/models_loading_gltf.c
index 15138e38..36400675 100644
--- a/examples/models/models_loading_gltf.c
+++ b/examples/models/models_loading_gltf.c
@@ -1,25 +1,16 @@
/*******************************************************************************************
*
* raylib [models] example - Load models gltf
*
-* This example has been created using raylib 3.5 (www.raylib.com)
+* This example has been created using raylib 4.2 (www.raylib.com)
* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
-* NOTE: To export a model from Blender, make sure it is not posed, the vertices need to be
-* in the same position as they would be in edit mode.
-* Also make sure the scale parameter of your models is set to 0.0,
-* scaling can be applied from the export menu.
-*
-* Example contributed by Hristo Stamenov (@object71) and reviewed by Ramon Santamaria (@raysan5)
-*
-* Copyright (c) 2021 Hristo Stamenov (@object71) and Ramon Santamaria (@raysan5)
+* Copyright (c) 2022 Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
-#define MAX_GLTF_MODELS 8
-
//------------------------------------------------------------------------------------
// Program main entry point
//------------------------------------------------------------------------------------
@@ -30,7 +21,7 @@ int main(void)
const int screenWidth = 800;
const int screenHeight = 450;
- InitWindow(screenWidth, screenHeight, "raylib [models] example - model");
+ InitWindow(screenWidth, screenHeight, "raylib [models] example - loading gltf");
// Define the camera to look into our 3d world
Camera camera = { 0 };
@@ -40,18 +31,8 @@ int main(void)
camera.fovy = 45.0f; // Camera field-of-view Y
camera.projection = CAMERA_PERSPECTIVE; // Camera mode type
- // Load some models
- Model model[MAX_GLTF_MODELS] = { 0 };
- model[0] = LoadModel("resources/models/gltf/raylib_32x32.glb");
- model[1] = LoadModel("resources/models/gltf/rigged_figure.glb");
- model[2] = LoadModel("resources/models/gltf/GearboxAssy.glb");
- model[3] = LoadModel("resources/models/gltf/BoxAnimated.glb");
- model[4] = LoadModel("resources/models/gltf/AnimatedTriangle.gltf");
- model[5] = LoadModel("resources/models/gltf/AnimatedMorphCube.glb");
- model[6] = LoadModel("resources/models/gltf/vertex_colored_object.glb");
- model[7] = LoadModel("resources/models/gltf/girl.glb");
-
- int currentModel = 0;
+ // Loaf gltf model
+ Model model = LoadModel("resources/models/gltf/robot.glb");
Vector3 position = { 0.0f, 0.0f, 0.0f }; // Set model position
@@ -66,18 +47,6 @@ int main(void)
// Update
//----------------------------------------------------------------------------------
UpdateCamera(&camera); // Update our camera with inputs
-
- if (IsKeyReleased(KEY_RIGHT))
- {
- currentModel++;
- if (currentModel == MAX_GLTF_MODELS) currentModel = 0;
- }
-
- if (IsKeyReleased(KEY_LEFT))
- {
- currentModel--;
- if (currentModel < 0) currentModel = MAX_GLTF_MODELS - 1;
- }
//----------------------------------------------------------------------------------
// Draw
@@ -88,7 +57,7 @@ int main(void)
BeginMode3D(camera);
- DrawModel(model[currentModel], position, 1.0f, WHITE);
+ DrawModel(model, position, 1.0f, WHITE);
DrawGrid(10, 1.0f); // Draw a grid
EndMode3D();
@@ -99,8 +68,8 @@ int main(void)
// De-Initialization
//--------------------------------------------------------------------------------------
- for (int i = 0; i < MAX_GLTF_MODELS; i++) UnloadModel(model[i]); // Unload models
-
+ UnloadModel(model); // Unload model and meshes/material
+
CloseWindow(); // Close window and OpenGL context
//--------------------------------------------------------------------------------------
@@ -1,25 +1,16 @@
/*******************************************************************************************
*
-* raylib [models] example - Load models gltf
+* raylib [models] example - loading gltf
*